ManagedDisposer class

Used to invoke, and remove references to, a Disposer before disposal of the parent object.

Constructors

ManagedDisposer(Disposer? _disposer)

Properties

didDispose → Future<Null>
A Future that will complete when this object has been disposed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
Whether this object has been disposed.
no setter
isDisposedOrDisposing → bool
Whether this object has been disposed or is disposing.
no setter
isDisposing → bool
Whether this object is in the process of being disposed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<Null>
Dispose of the object, cleaning up to prevent memory leaks.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited